linbox: Linear algebra with dense, sparse, structured matrices over the integers and finite fields
==================================================================================================

Description
-----------

LinBox is a C++ template library for exact,
high-performance linear algebra computation with dense, sparse, and
structured matrices over the integers and over finite fields.

License
-------

LGPL V2 or later


Upstream Contact
----------------

-  https://linalg.org/
-  <linbox-devel@googlegroups.com>
-  <linbox-use@googlegroups.com>
